/* global __dirname, require, module*/

const webpack = require('webpack');
const UglifyJSPlugin = require('uglifyjs-webpack-plugin');
const path = require('path');
const env = require('yargs').argv.env; // use --env with webpack 2

let libraryName = 'library';

let plugins = [], outputFile;

if (env === 'build') {
  plugins.push(new UglifyJSPlugin());
  outputFile = libraryName + '.min.js';
} else {
  outputFile = libraryName + '.js';
}

const config = {
  entry: __dirname + '/src/index.js',
  devtool: 'source-map',
  target: 'node',
  output: {
    path: __dirname + '/lib',
    filename: outputFile,
    library: libraryName,
    libraryTarget: 'umd',
    umdNamedDefine: true
  },
  module: {
    rules: [
      {
        test: /(\.jsx|\.js)$/,
        loader: 'babel-loader',
        exclude: /(node_modules|bower_components)/
      },
      {
        test: /(\.jsx|\.js)$/,
        loader: 'eslint-loader',
        exclude: /node_modules/
      }
    ]
  },
  resolve: {
    modules: [
      "node_modules",
      path.resolve(__dirname, 'src'),
      path.resolve(__dirname, 'src/DTO'),
      path.resolve(__dirname, 'src/Resources'),
      path.resolve(__dirname, 'src/Utils')
    ],
    extensions: ['.json', '.js']
  },
  plugins: plugins
};

module.exports = config;
